@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, print_function
 
 import os
+import sys
 from platform import platform
 from itertools import product
 import pytest
@@ -84,7 +85,8 @@ def test_different_encoding():
                   'sqlite:///%s::t' % db, encoding=encoding)
         result = odo(sql, list)
 
-    NULL = u'' if 'windows' not in platform().lower() else None
+    NULL = u''
+
     expected = [(u'1958.001.500131-1A', 1, NULL, NULL, 899),
                 (u'1958.001.500156-6', 1, NULL, NULL, 899),
                 (u'1958.001.500162-1', 1, NULL, NULL, 899),
